@@ -8,6 +8,7 @@ import json
 from telapi.schema import SCHEMA
 from telapi import VERSION
 
+__ALL__ = ['exceptions']
 
 
 USER_AGENT = "TelAPI-Python/%s (%s %s)" % (VERSION, platform.system(), platform.release())
@@ -378,10 +379,10 @@ class Client(object):
         self.auth_token  = auth_token or os.environ.get("TELAPI_AUTH_TOKEN")
         self.base_url    = base_url
 
-        if not self.account_sid or not self.account_sid.startswith("AC"):
+        if not self.account_sid or not self.account_sid.startswith("AC") or len(self.account_sid) != 34:
             raise exceptions.AccountSidError()
 
-        if not self.auth_token:
+        if not self.auth_token or len(self.auth_token) != 32:
             raise exceptions.AuthTokenError()
 
     def _send_request(self, resource_uri, method, params=None):
@@ -410,7 +411,7 @@ class Client(object):
                     error = json.loads(response.content)
                     raise exceptions.RequestError("Error code %s. %s. More info at %s" % (error["code"], error["message"], error["more_info"]), error_code=error["code"], http_code=response.status_code)
                 except ValueError:
-                    raise exceptions.RequestError("Errror requesting %s to '%s'. Status code: %s" % (method, url, response.status_code), http_code=response.status_code)
+                    raise exceptions.RequestError("Error requesting %s to '%s'. Status code: %s" % (method, url, response.status_code), http_code=response.status_code)
 
         # print
         # print response.content
